@@ -9,7 +9,7 @@ use Symbol;
 use File::Spec;
 use Carp;
 
-$VERSION = '0.10';
+$VERSION = '0.20';
 
 __PACKAGE__->mk_classdata(dir => (__FILE__ =~ /(.+)\.pm/)[0]);
 __PACKAGE__->mk_classdata(languages => {});
@@ -71,20 +71,21 @@ sub assert_lang {
 
 
 sub code2country {
-    my ($self, $code, $lang) = @_;
+    my $self = shift;
+    my $code = shift
+	or return;
     
-    return unless defined $code;
-    return if ($code =~ /\W/);
+    return if $code =~ /\W/;
     
-    $lang ||= $self->{lang} || 'en';
+    my $lang = shift || $self->{lang} || 'en';
     my $language = $self->_load_data($lang);
 
     if ($code =~ /^\d+$/) {
         return $language->[CODE]->[LOCALE_CODE_NUMERIC]->{$code + 0};
     } elsif (length($code) == 2) {
-        return $language->[CODE]->[LOCALE_CODE_ALPHA_2]->{$code};
+        return $language->[CODE]->[LOCALE_CODE_ALPHA_2]->{uc($code)};
     } elsif (length($code) == 3) {
-        return $language->[CODE]->[LOCALE_CODE_ALPHA_3]->{$code};
+        return $language->[CODE]->[LOCALE_CODE_ALPHA_3]->{uc($code)};
     }
     return;
 }
@@ -125,7 +126,8 @@ sub all_country_names {
 }
 
 sub _load_data {
-    my ($self, $lang) = @_;
+    my $self = shift;
+    my $lang = lc shift;
 
     my $languages = $self->languages;
     my $language = $languages->{$lang};
@@ -160,7 +162,7 @@ sub _load_data {
 
 sub _open_dat {
     my $self = shift;
-    my $filename = lc(shift || '');
+    my $filename = shift || '';
     my $fh = gensym;	# required before Perl 5.6
     my @errors;
     my $lang;		# stores the actual name used for loading
@@ -197,33 +199,37 @@ __END__
 
 Locale::Country::Multilingual - mapping ISO codes to localized country names
 
+=head1 VERSION
+
+Version 0.20
+
 =head1 SYNOPSIS
 
     use Locale::Country::Multilingual;
 
     my $lcm = Locale::Country::Multilingual->new();
-    $country = $lcm->code2country('jp');        # $country gets 'Japan'
-    $country = $lcm->code2country('chn');       # $country gets 'China'
+    $country = $lcm->code2country('JP');        # $country gets 'Japan'
+    $country = $lcm->code2country('CHN');       # $country gets 'China'
     $country = $lcm->code2country('250');       # $country gets 'France'
-    $code    = $lcm->country2code('Norway');    # $code gets 'no'
+    $code    = $lcm->country2code('Norway');    # $code gets 'NO'
     
     $lcm->set_lang('zh'); # set default language to Chinese
-    $country = $lcm->code2country('cn');        # $country gets '中国'
-    $code    = $lcm->country2code('日本');      # $code gets 'jp'
+    $country = $lcm->code2country('CN');        # $country gets '中国'
+    $code    = $lcm->country2code('日本');      # $code gets 'JP'
     
     @codes   = $lcm->all_country_codes();
     @names   = $lcm->all_country_names();
     
     # more heavy call
     my $lang = 'en';
-    $country = $lcm->code2country('cn', $lang);        # $country gets 'China'
+    $country = $lcm->code2country('CN', $lang);        # $country gets 'China'
     $lang = 'zh';
-    $country = $lcm->code2country('cn', $lang);        # $country gets '中国'
+    $country = $lcm->code2country('CN', $lang);        # $country gets '中国'
     
     my $CODE = 'LOCALE_CODE_ALPHA_2'; # by default
-    $code    = $lcm->country2code('Norway', $CODE);    # $code gets 'no'
+    $code    = $lcm->country2code('Norway', $CODE);    # $code gets 'NO'
     $CODE = 'LOCALE_CODE_ALPHA_3';
-    $code    = $lcm->country2code('Norway', $CODE);    # $code gets 'nor'
+    $code    = $lcm->country2code('Norway', $CODE);    # $code gets 'NOR'
     $CODE = 'LOCALE_CODE_NUMERIC';
     $code    = $lcm->country2code('Norway', $CODE);    # $code gets '578'
     $code    = $lcm->country2code('挪威', $CODE, 'zh');    # with lang=zh
@@ -236,9 +242,21 @@ Locale::Country::Multilingual - mapping ISO codes to localized country names
 =head1 DESCRIPTION
 
 C<Locale::Country::Multilingual> is an OO replacement for
-L<Locale::Country|Locale::Country>, that supports country names in several
+L<Locale::Country|Locale::Country>, and supports country names in several
 languages.
 
+=head2 Incompatibility Notice
+
+C<ISO-3166> defines country codes in upper case letters. C<ISO-639> defines
+language codes in lower case letters.
+
+Beginning with release version 0.20 method L</country2code> returns country
+codes in capital letters. On the input side all methods accept country and
+language codes in any case for maximum convenience.
+
+This document uses upper case letters for country codes and lower case
+letters for language codes.
+
 =head2 Language Codes
 
 A language is selected by a two-letter language code as described by
@@ -275,7 +293,7 @@ language data that is loaded before forking, is shared by all processes.
 
 The last argument can be a reference to a hash of options.
 
-The only option ATM is C<use_io_layer>. See
+The only option ATM is C<use_io_layer> and works for Perl 5.8 and higher. See
 L<Locale::Country::Multilingual::Unicode|Locale::Country::Multilingual::Unicode>
 for more information.
 
@@ -332,8 +350,8 @@ this way:
 
 =head2 code2country
 
-  $country = $lcm->code2country('gb');
-  $country = $lcm->code2country('gb', 'zh');
+  $country = $lcm->code2country('GB');
+  $country = $lcm->code2country('GB', 'zh');
 
 Turns an ISO 3166-1 code into a country name in the current language.
 The default language is C<"en">.
@@ -393,27 +411,156 @@ Returns an unsorted list of country names in the current or given locale.
 
 =item en English
 
+=item bg Bulgarian
+
+=item bn Bengali
+
+=item ca Catalan
+
+=item cs Czech
+
+=item cy Welsh
+
+=item da Danish
+
+=item de German
+
+=item dz Dzongkha
+
+=item el Greek
+
+=item eo Esperanto
+
+=item es Spanish
+
+=item et Estonian
+
+=item eu Basque
+
+=item fa Persian
+
+=item fi Finnish
+
+=item fo Faroese
+
+=item fr French
+
+=item ga Irish
+
+=item gl Galician
+
+=item gu Gujarati
+
+=item he Hebrew
+
+=item hi Hindi
+
+=item hr Croatian
+
+=item hu Hungarian
+
+=item hy Armenian
+
+=item id Indonesian
+
+=item ii Sichuan Yi
+
+=item is Icelandic
+
+=item it Italian
+
+=item ja Japanese
+
+=item ka Georgian
+
+=item km Central Khmer
+
+=item kn Kannada
+
+=item ko Korean
+
+=item ln Lingala
+
+=item lo Lao
+
+=item lt Lithuanian
+
+=item lv Latvian
+
+=item mk Macedonian
+
+=item ml Malayalam
+
+=item mn Mongolian
+
+=item ms Malay
+
+=item mt Maltese
+
+=item my Burmese
+
+=item nb Norwegian Bokmål
+
+=item ne Nepali
+
+=item nl Dutch
+
+=item nn Norwegian Nynorsk
+
+=item no Norwegian
+
+=item pl Polish
+
+=item ps Pushto
+
+=item pt Portuguese
+
+=item ro Romanian
+
+=item ru Russian
+
+=item se Northern Sami
+
+=item sk Slovak
+
+=item sl Slovenian
+
+=item so Somali
+
+=item sq Albanian
+
+=item sr Serbian
+
+=item sv Swedish
+
+=item sw Swahili
+
+=item ta Tamil
+
+=item te Telugu
+
+=item th Thai
+
+=item to Tonga
+
+=item tr Turkish
+
+=item uk Ukrainian
+
+=item ur Urdu
+
+=item uz Uzbek
+
+=item vi Vietnamese
+
 =item zh (zh-cn) Chinese Simp.
 
 =item zh-tw Chinese Trad.
 
-=item it Italian
-
-=item es Spanish
-
-=item pt Portuguese
-
-=item de German
-
-=item fr French
-
-=item ja Japanese
-
-=item no Norwegian
-
 =back
 
-Other languages are welcome to send by email.
+Language files are more or less (in-)complete and fall back to English.
+Corrections, additions and more languages are highly appreciated.
 
 =head2 Deprecated languages
 
@@ -439,7 +586,8 @@ ISO 639 L<http://en.wikipedia.org/wiki/ISO_639>,
 ISO 3166 L<http://en.wikipedia.org/wiki/ISO_3166>,
 RFC 2616 L<http://www.ietf.org/rfc/rfc2616.txt>
 RFC 4646 L<http://www.ietf.org/rfc/rfc4646.txt>,
-RFC 4647 L<http://www.ietf.org/rfc/rfc4647.txt>
+RFC 4647 L<http://www.ietf.org/rfc/rfc4647.txt>,
+Unicode CLDR Project L<http://unicode.org/cldr/>
 
 =head1 ACKNOWLEDGEMENTS
 
@@ -447,7 +595,9 @@ Thanks to michele ongaro for Italian/Spanish/Portuguese/German/French/Japanese d
 
 Thanks to Andreas Marienborg for Norwegian dat file.
 
-=head1 AUTHOR
+Thanks to all contributors of the Unicode CLDR Project.
+
+=head1 AUTHORS
 
 Fayland Lam <fayland at gmail.com>
 
@@ -455,7 +605,7 @@ Bernhard Graf <graf at cpan.org>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2008 *AUTHOR* all rights reserved.
+Copyright 2007-2008 by the aforementioned authors.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
